#!/bin/sh
# Run this to generate DEBIAN and RPM package.

CONFIG_PKG_NAME=`cat config.h | grep PACKAGE_NAME | awk '{ print substr($0, match($0, "\"")+1, length($0))}'`
CONFIG_PKG_NAME=`echo $CONFIG_PKG_NAME | awk '{ print substr($0, 1, match($0, "\"")-1)}'`
CONFIG_PKG_VERSION=`cat config.h | grep PACKAGE_VERSION | awk '{ print substr($0, match($0, "\"")+1, length($0))}'`
CONFIG_PKG_VERSION=`echo $CONFIG_PKG_VERSION | awk '{ print substr($0, 1, match($0, "\"")-1)}'`
CONFIG_PKG_RELEASE=`cat config.h | grep RPM_DEB_PACKAGE | awk '{ print substr($0, match($0, "\"")+1, length($0))}'`
CONFIG_PKG_RELEASE=`echo $CONFIG_PKG_RELEASE | awk '{ print substr($0, 1, match($0, "\"")-1)}'`

# Check to make sure that we could read config.h
# if not, we may not be called from the right directory!
if test "x$CONFIG_PKG_NAME" = x; then
	echo "ERROR: Please make sure to launch this script from the package"
	echo "       root directory. You must have compiled first."
	exit;
fi

# Verify that the package has been compiled.
PACKAGE_BIN=`ls src/$CONFIG_PKG_NAME | wc -l`

if test $PACKAGE_BIN -lt 1; then
	echo "ERROR: src/$CONFIG_PKG_NAME not found."
	echo "Type \"./autogen.sh\" and then \"make\" to compile."
	exit
fi


# --- Determine the processor architecture ---
# We support only i386 and amd64 with this implementation.
SIZE_VOID_PTR=`cat config.h | grep SIZEOF_VOID_P | awk '{ print substr($0, match($0, "_P")+2, length($0))}'`

if test $SIZE_VOID_PTR -eq 4; then
	ARCH_NAME="i386"
else
	ARCH_NAME="amd64"
fi

# --- Estimate package size by copying all files and tar with no compression ---
PACKAGE_FILE=$CONFIG_PKG_NAME-$CONFIG_PKG_VERSION
APPROX_PKG_NAME=$PACKAGE_FILE
mkdir -p "packaging/"$APPROX_PKG_NAME
cd packaging
cp ../data/* $APPROX_PKG_NAME
cp ../install-data/* $APPROX_PKG_NAME
cp ../src/hdjcpl $APPROX_PKG_NAME
cp ../ChangeLog $APPROX_PKG_NAME/changelog
gzip $APPROX_PKG_NAME/changelog
tar -cf ${APPROX_PKG_NAME}.tar ${APPROX_PKG_NAME}/
tar -z -cf ${PACKAGE_FILE}.tar.gz ${APPROX_PKG_NAME}/
PKG_SIZE=`ls -l ${APPROX_PKG_NAME}.tar | awk '{printf "%s",$5}'`
rm ${APPROX_PKG_NAME}.tar
rm -r ${APPROX_PKG_NAME}
PKG_SIZE=`expr $PKG_SIZE + 1023`
PKG_SIZE=`expr $PKG_SIZE / 1024`

echo
echo "Package name: "$CONFIG_PKG_NAME
echo "Version: "$CONFIG_PKG_VERSION
echo "Release: "$CONFIG_PKG_RELEASE
echo "Architecture: "$ARCH_NAME
echo "Total size: "$PKG_SIZE kb
echo
echo "--- Found in control.basic ---"
cat control.basic | grep Maintainer
echo

# --- Prepare RPM package. ---
mkdir -p rpm/BUILD
mkdir -p rpm/RPMS
mkdir -p rpm/SOURCES
mkdir -p rpm/SPECS
mkdir -p rpm/SRPMS
mv ${PACKAGE_FILE}.tar.gz rpm/SOURCES
RPM_TOP_DIR=`pwd`"/rpm"
DEB_TOP_DIR=`pwd`
echo %define _topdir $RPM_TOP_DIR > rpm/SPECS/hdjcpl.spec
echo Version: $CONFIG_PKG_VERSION >> rpm/SPECS/hdjcpl.spec
echo Release: $CONFIG_PKG_RELEASE >> rpm/SPECS/hdjcpl.spec
cat spec.basic >> rpm/SPECS/hdjcpl.spec
echo >> rpm/SPECS/hdjcpl.spec
echo %changelog >> rpm/SPECS/hdjcpl.spec
cat ../ChangeLog >> rpm/SPECS/hdjcpl.spec
cd rpm/SPECS
echo "Creating RPM package... (you may need to enter sudo password)"
sudo rpmbuild -bb hdjcpl.spec
cd ..
sudo mv RPMS/*/*.rpm ..
cd ..
sudo rm -rf rpm

# --- Prepare DEB package ---
DEB_PACKAGE_FILE=$CONFIG_PKG_NAME"_"$CONFIG_PKG_VERSION-$CONFIG_PKG_RELEASE"_"$ARCH_NAME
mkdir -p $DEB_PACKAGE_FILE/DEBIAN
mkdir -p $DEB_PACKAGE_FILE/usr/bin
mkdir -p $DEB_PACKAGE_FILE/usr/share/applications
mkdir -p $DEB_PACKAGE_FILE/usr/share/hercules-hdjcpl
mkdir -p $DEB_PACKAGE_FILE/usr/share/icons
mkdir -p $DEB_PACKAGE_FILE/usr/share/doc/hdjcpl

cp ../src/hdjcpl $DEB_PACKAGE_FILE/usr/bin
cp ../data/* $DEB_PACKAGE_FILE/usr/share/hercules-hdjcpl
cp ../install-data/hdjcpl.desktop $DEB_PACKAGE_FILE/usr/share/applications
cp ../install-data/hdjcpl.xpm $DEB_PACKAGE_FILE/usr/share/icons
cp ../ChangeLog $DEB_PACKAGE_FILE/usr/share/doc/hdjcpl/changelog
gzip $DEB_PACKAGE_FILE/usr/share/doc/hdjcpl/changelog
echo Version: $CONFIG_PKG_VERSION-$CONFIG_PKG_RELEASE > $DEB_PACKAGE_FILE/DEBIAN/control
echo Installed-Size: $PKG_SIZE >> $DEB_PACKAGE_FILE/DEBIAN/control
echo Architecture: $ARCH_NAME >> $DEB_PACKAGE_FILE/DEBIAN/control
cat control.basic >> $DEB_PACKAGE_FILE/DEBIAN/control

echo "Creating DEBIAN package... (you may need to enter sudo password)"
sudo dpkg-deb --build $DEB_PACKAGE_FILE
rm -r $DEB_PACKAGE_FILE

cd ..
echo
echo
echo "Debian and RPM packages version "$CONFIG_PKG_VERSION" (release "$CONFIG_PKG_RELEASE")"
echo "should have been generated in directory: /packaging"
echo


