/////////////////////////////////////////////////////////////////////////////
// Name:        bulkinterface.h
// Purpose:     Access the custom Hercules Driver which interface to
//		Hercules DJ products. The HID raw data is read/write via
//		the same custom driver.
//
//		Recently, some changes has been made in the Linux
//		kernel (HIDRAW component) to provide a way to retrieve
//		the physical location (which is required to bind multiple
//		driver (HID, ALSA, our custom driver) together when there
//		is multiple identical (same VID, PID, REV) device found.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     03/19/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License.
/////////////////////////////////////////////////////////////////////////////

#include "commondefs.h"

#ifndef __BULK_INTERFACE_H__
#define __BULK_INTERFACE_H__

class CBulkInterface
{
public:
	CBulkInterface( void );
	~CBulkInterface( );

	bool Open( int nDeviceIndex, DJ_DEVICE_STATE *pState );
	bool Close(DJ_DEVICE_STATE *pState );
	bool RetrieveState( DJ_DEVICE_STATE *pState );
	bool IsDeviceAlive( DJ_DEVICE_STATE *pState );

	bool RegisterNetLink( DJ_DEVICE_STATE *pState );
	bool UnRegisterNetLink( DJ_DEVICE_STATE *pState );

	// --- Update HID ---
	bool UpdateHIDSet_DJConsoleMk2( DJ_DEVICE_STATE *pState );

	// --- Set Properties ---
	bool EnableDJMode( bool bEnable, DJ_DEVICE_STATE *pState );				// DJC
	bool EnableDJMouse( bool bEnable, DJ_DEVICE_STATE *pState );				// DJC, Mk2, MP3
	bool EnableTalkover( bool bEnable, DJ_DEVICE_STATE *pState );				// DJC, Mk2, Rmx
	bool LockJogWheel( JOG_WHEELS_DIS eJogWheelDisable, DJ_DEVICE_STATE *pState );		// Rmx, Steel
	bool MuteChannel34( bool bMute34, DJ_DEVICE_STATE *pState );				// DJC, Mk2, Rmx
	bool SetAudioSource( int nDeck, AUDIO_SOURCE eAudioSource, DJ_DEVICE_STATE *pState );	// Mk2
	bool SetCrossFaderCurve( CROSSFADER_SEL eCurve, DJ_DEVICE_STATE *pState );		// Mk2
	bool SetHeadphoneToMainOut( bool bHeadphoneToMain, DJ_DEVICE_STATE *pState );		// DJC
	bool SetJogsSensitivity( JOGS_SENSITIVE eSensitivity, DJ_DEVICE_STATE *pState );	// Rmx, Steel
	bool SetMidiChannel( int nMidiChannel, DJ_DEVICE_STATE *pState );			// Rmx, MP3, Steel
	bool SetMidiInput( MIDI_INPUT_SEL eMidiInput, DJ_DEVICE_STATE *pState );		// DJC
	bool SetSampleRate( int nSampleRate, DJ_DEVICE_STATE *pState );				// DJC
	bool SetRecordInput( RECORD_INPUT eRecordInput, DJ_DEVICE_STATE *pState );		// DJC, Mk2, Rmx
	bool SetTalkoverAttenuation( int nTalkover, DJ_DEVICE_STATE *pState );			// DJC, Mk2, Rmx
	bool SetOutputMainHwMix( OUT_HWARE_MIX eHardwareMix, DJ_DEVICE_STATE *pState );		// Rmx
	bool UseExternalMixer( bool bUseExternalMixer, DJ_DEVICE_STATE *pState );		// Mk2
	

protected:
	int  SingleBulkIoctl( int nBulkHandle, int nRequest, void *pParam );
	int  BulkIoctl( int nRequest, void *pParam );
	bool RetrieveState_DJConsole( DJ_DEVICE_STATE *pState );
	bool RetrieveState_DJConsoleMk2( DJ_DEVICE_STATE *pState );
	bool RetrieveState_DJControlMP3( DJ_DEVICE_STATE *pState );
	bool RetrieveState_DJConsoleRmx( DJ_DEVICE_STATE *pState );
	bool RetrieveState_DJControlSteel( DJ_DEVICE_STATE *pState );
	bool CheckIfSupported(DJ_DEVICE_STATE *pState, int nSupportFlags);

private:
	int m_nBulkHandle;
};

#endif

