/////////////////////////////////////////////////////////////////////////////
// Name:        dmanager.h
// Purpose:     Device Manager provide a single set of functions for all
//		devices. Not all functions are available per DJ products.
//		Some functions are driven via different interfaces and are
//		re-routed in this class.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     03/19/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License.
/////////////////////////////////////////////////////////////////////////////

#include <wx/wx.h>
#include <signal.h>

#include "bulkinterface.h"
#include "alsainterface.h"
#include "drivernotification.h"
#include "hidnotification.h"

#ifndef __DMANAGER_H__
#define __DMANAGER_H__

extern DJ_DEVICE_STATE		g_DEVICE_INFO[MAX_DEVICES];
extern volatile int		g_RescanDeviceList;	// Flag used to identify a device change happen.

class CDManager
{
public:
	CDManager( void );
	~CDManager( );

	bool Initialize( wxDialog *pDlgParent );
	bool Uninitialize( void );
	bool ScanDevices( void );
	void UpdateAlsa( DJ_DEVICE_STATE *pState );
	bool SelectDevice( int nDeviceIndex );
	
	bool EnableDJMode( bool bEnable, DJ_DEVICE_STATE *pState );
	bool SetMidiChannel( int nMidiChannel, DJ_DEVICE_STATE *pState );
	bool SetJogsSensitivity( JOGS_SENSITIVE eSensitivity, DJ_DEVICE_STATE *pState );
	bool LockJogWheel( JOG_WHEELS_DIS eJogWheelDisable, DJ_DEVICE_STATE *pState );
	bool SetOutputMainHwMix( OUT_HWARE_MIX eHardwareMix, DJ_DEVICE_STATE *pState );
	bool SetRecordInput( RECORD_INPUT eRecordInput, DJ_DEVICE_STATE *pState );
	bool SetMidiInput( MIDI_INPUT_SEL eMidiInput, DJ_DEVICE_STATE *pState );
	bool SetHeadphoneToMainOut( bool bHeadphoneToMain, DJ_DEVICE_STATE *pState );

	bool SetMute( DJ_DEVICE_STATE *pDeviceState, int nStereoChannel, bool bMute );
	bool SetVolume( DJ_DEVICE_STATE *pDeviceState, int nChannel, unsigned short usVolume );
	bool EnableTalkover( bool bEnable, DJ_DEVICE_STATE *pState );
	bool SetTalkoverAttenuation( int nTalkover, DJ_DEVICE_STATE *pState );
	bool EnableDJMouse( bool bEnable, DJ_DEVICE_STATE *pState );
	bool UseExternalMixer( bool bUseExternalMixer, DJ_DEVICE_STATE *pState );
	bool SetCrossFaderCurve( CROSSFADER_SEL eCurve, DJ_DEVICE_STATE *pState );
	bool SetSampleRate( int nSampleRate, DJ_DEVICE_STATE *pState );

	bool SetLockState( int nDeck, bool bLock, DJ_DEVICE_STATE *pState );

protected:

	static void signal_handler(int sig, siginfo_t *sigInfo, void *uap);
	int 			m_nPreviousDeviceIndex;
	CBulkInterface		m_BulkInterface;
	CAlsaInterface		m_AlsaInterface;
	CDriverNotification    *m_pDriverNotification;
	CHIDNotification       *m_pHidNotification;

private:
};

#endif

