/////////////////////////////////////////////////////////////////////////////
// Name:        gcheckbox.cpp
// Purpose:     GUI check box implementation using wxWidgets.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     04/04/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "gcheckbox.h"

CGCheckBox::CGCheckBox( PEVENT_LIST pEventList, int nControlID, int nPosX, int nPosY, 
	int nImageSizeX, int nImageSizeY, const char *szLabel, int nWidth, int nHeight,
	wxMemoryDC *pSkinMemDC, wxMemoryDC *pSkinAlphaMemDC, int nStateCount, 
	PCHECKBOX_STATE_INFO pStateInfo, unsigned long ulAlign ) :
		CGControl(pEventList, nControlID, GCONTROL_TYPE_BUTTON, nPosX, nPosY, nWidth, nHeight)
{
	int i, j;

	m_pSkinMemDC = pSkinMemDC;
	m_pSkinAlphaMemDC = pSkinAlphaMemDC;
	m_nStateCount = nStateCount;
	m_pStateInfo = NULL;
	if (m_nStateCount>0) { 
		m_pStateInfo = new CHECKBOX_STATE_INFO[m_nStateCount];
		for(i=0;i<m_nStateCount;++i) {
			for(j=0;j<4;++j) {
				m_pStateInfo[i].coordinates[j].x = pStateInfo[i].coordinates[j].x;
				m_pStateInfo[i].coordinates[j].y = pStateInfo[i].coordinates[j].y;
				m_pStateInfo[i].coordinates[j].r = pStateInfo[i].coordinates[j].r;
				m_pStateInfo[i].coordinates[j].g = pStateInfo[i].coordinates[j].g;
				m_pStateInfo[i].coordinates[j].b = pStateInfo[i].coordinates[j].b;
			}
			m_pStateInfo[i].nProcessAlpha = pStateInfo[i].nProcessAlpha;
		}
	}

	m_nCurrentState = 0;
	m_nCurrentSubState = CHECKBOX_STATE_NORMAL;
	m_nImageSizeX = nImageSizeX;
	m_nImageSizeY = nImageSizeY;
	strncpy(m_szLabel, szLabel, 511);
	m_nFontSize = 8;
	m_nFontBold = 0;
	m_nFontItalic = 0;
	m_ulAlign = ulAlign;
}

CGCheckBox::~CGCheckBox()
{
	if (m_pStateInfo!=NULL)
		delete m_pStateInfo;
}

// ---------------------------------------------------------------------------
// Function: SetFontSize
// ---------------------------------------------------------------------------
void CGCheckBox::SetFontSize( int nSize )
{
	m_nFontSize = nSize;
}

// ---------------------------------------------------------------------------
// Function: SetFontAttributes
// ---------------------------------------------------------------------------
void CGCheckBox::SetFontAttributes( int nBold, int nItalic )
{
	m_nFontBold = nBold;
	m_nFontItalic = nItalic;
}

// ---------------------------------------------------------------------------
// Function: SetFontName
// ---------------------------------------------------------------------------
void CGCheckBox::SetFontName( char *strFontName )
{
	strcpy(m_szFontName, strFontName);
}

// ---------------------------------------------------------------------------
// Function: GetLabel
// ---------------------------------------------------------------------------
int CGCheckBox::GetLabel(char *szLabel)
{
	if (szLabel!=NULL)
		strcpy(szLabel, m_szLabel);
	return (int) strlen(m_szLabel);
}

// ---------------------------------------------------------------------------
// Function: SetLabel
// ---------------------------------------------------------------------------
void CGCheckBox::SetLabel(char *szLabel)
{
	strncpy(m_szLabel, szLabel, 511);
}

// ---------------------------------------------------------------------------
// Function: GetState
// ---------------------------------------------------------------------------
int CGCheckBox::GetState()
{
	return m_nCurrentState;
}

// ---------------------------------------------------------------------------
// Function: SetState
// ---------------------------------------------------------------------------
void CGCheckBox::SetState(int nState)
{
	if (nState>=0 && nState<m_nStateCount)
		m_nCurrentState = nState;
}

// ---------------------------------------------------------------------------
// Function: Enable
// ---------------------------------------------------------------------------
void CGCheckBox::Enable( bool bEnable )
{
	CGControl::Enable(bEnable);
	if (!m_bEnable)
		m_nCurrentSubState = CHECKBOX_STATE_DISABLE;
	else
		m_nCurrentSubState = CHECKBOX_STATE_NORMAL;
}

// ---------------------------------------------------------------------------
// Function: Paint
//
// Paint a bitmap for the checkbox and the text next to it.
// ---------------------------------------------------------------------------
void CGCheckBox::Paint( wxDC *pDC, PREFRESH_RECT refreshRect )
{
	wxFont	font(m_nFontSize, wxFONTFAMILY_DEFAULT, 
		(m_nFontItalic) ? wxFONTSTYLE_ITALIC : wxFONTSTYLE_NORMAL, 
		(m_nFontBold) ? wxFONTWEIGHT_BOLD : wxFONTWEIGHT_NORMAL);
	wxColour	color;
	wxSize		size;
	int		ix, iy, tx, ty, tw, th;	// Coordinate of image (ix,iy), text (tx,ty), text (width,height)

	if (m_bHide || pDC==NULL || m_pSkinMemDC==NULL || m_pStateInfo==NULL || m_nCurrentState>=m_nStateCount)
		return;

	// --- If button is outside of the region, do not refresh it ---
	if (refreshRect->x>m_nPosX+m_nWidth || refreshRect->x+refreshRect->w<m_nPosX)
		return;
	if (refreshRect->y>m_nPosY+m_nHeight || refreshRect->y+refreshRect->h<m_nPosY)
		return;

	pDC->SetFont(font);
	size = pDC->GetTextExtent(m_szLabel);
	tw = size.GetWidth();
	th = size.GetHeight();

	// --- Align Horizontal ---
	if ((m_ulAlign&ALIGN_MASK)==ALIGN_RIGHT) {
		ix = m_nPosX+m_nWidth-m_nImageSizeX;
		if (ix<m_nPosX) ix = m_nPosX;
		tx = ix - 4 - tw;
	}
	else {
		ix = m_nPosX;
		if (ix<m_nPosX) ix = m_nPosX;
		tx = ix + m_nImageSizeX + 4;
	}
	if (tx<m_nPosX) tx = m_nPosX;

	// --- Align Vertical ---
	if ((m_ulAlign&VALIGN_MASK)==VALIGN_TOP) {
		iy = m_nPosY;
		ty = m_nPosY;
	}
	else if ((m_ulAlign&VALIGN_MASK)==VALIGN_CENTER) {
		iy = m_nPosY + (m_nHeight-m_nImageSizeY)/2;
		ty = m_nPosY + (m_nHeight - th)/2;
	}
	else {
		iy = m_nPosY + m_nHeight - m_nImageSizeY;
		ty = m_nPosY + m_nHeight - th;
	}
	if (iy<m_nPosY) iy = m_nPosY;
	if (ty<m_nPosY) ty = m_nPosY;


	// --- Paint with or without transparency (stored in a .PNG file) ---
	if (m_pStateInfo[m_nCurrentState].nProcessAlpha) {
		pDC->Blit(ix, iy, m_nImageSizeX, m_nImageSizeY, m_pSkinAlphaMemDC, 
			m_pStateInfo[m_nCurrentState].coordinates[m_nCurrentSubState].x, 
			m_pStateInfo[m_nCurrentState].coordinates[m_nCurrentSubState].y, wxAND);
		pDC->Blit(ix, iy, m_nImageSizeX, m_nImageSizeY, m_pSkinMemDC, 
			m_pStateInfo[m_nCurrentState].coordinates[m_nCurrentSubState].x, 
			m_pStateInfo[m_nCurrentState].coordinates[m_nCurrentSubState].y, wxOR);
	}
	else {
		pDC->Blit(ix, iy, m_nImageSizeX, m_nImageSizeY, m_pSkinMemDC, 
			m_pStateInfo[m_nCurrentState].coordinates[m_nCurrentSubState].x, 
			m_pStateInfo[m_nCurrentState].coordinates[m_nCurrentSubState].y, wxCOPY);
	}
	color.Set(m_pStateInfo[m_nCurrentState].coordinates[m_nCurrentSubState].r,
		m_pStateInfo[m_nCurrentState].coordinates[m_nCurrentSubState].g,
		m_pStateInfo[m_nCurrentState].coordinates[m_nCurrentSubState].b);
	pDC->SetTextForeground(color);
	pDC->DrawText(m_szLabel, tx, ty);
}

// ---------------------------------------------------------------------------
// Function: MouseEvent
//
// Change sub-state (normal, highlight, pressed) and fire the event
// GEVENT_BTN_CHANGE when the mouse left button is release within the control.
// ---------------------------------------------------------------------------
bool CGCheckBox::MouseEvent( int x, int y, int button, bool *bMouseOverCtrl, PREFRESH_RECT pRefreshRect )
{
	*bMouseOverCtrl = false;

	if (m_bHide || m_nCurrentSubState==CHECKBOX_STATE_DISABLE)
		return false;
	CGControl::MouseEvent(x,y,button,bMouseOverCtrl,pRefreshRect);

	if (*bMouseOverCtrl)
	{
		// Inside the control.
		if (button&GMOUSE_LEFT_DOWN) {
			if (m_nCurrentSubState!=CHECKBOX_STATE_PRESSED) {
				m_nCurrentSubState = CHECKBOX_STATE_PRESSED;
				return true;
			}
		}
		else {
			if (m_nCurrentSubState!=CHECKBOX_STATE_HIGHLIGHT) {
				if (m_nCurrentSubState==CHECKBOX_STATE_PRESSED) {
					m_nCurrentState = (m_nCurrentState+1)%m_nStateCount;
					SetEvent(GEVENT_BTN_CHANGE, m_nCurrentState, 0);
				}
				m_nCurrentSubState = CHECKBOX_STATE_HIGHLIGHT;
				return true;
			}
		}
	}
	else
	{
		// Outside the control.
		if (m_nCurrentSubState!=CHECKBOX_STATE_NORMAL) {
			m_nCurrentSubState = CHECKBOX_STATE_NORMAL;
			return true;
		}
	}
	return false;
}

