/////////////////////////////////////////////////////////////////////////////
// Name:        gcombobox.h
// Purpose:     GUI Combo Box implementation using wxWidgets.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     04/26/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "gcontrol.h"

#ifndef _GUILLEMOT_COMBO_BOX_H_
#define _GUILLEMOT_COMBO_BOX_H_

#define MAX_LENGTH_COMBO_NAME	260

#define GCOMBO_BOX_DISABLE	0
#define GCOMBO_BOX_NORMAL	1
#define GCOMBO_BOX_HIGHLIGHT	2
#define GCOMBO_BOX_PRESS	3

typedef struct COMBO_ELEM {
	char		 szComboName[MAX_LENGTH_COMBO_NAME];
	COMBO_ELEM	*pNext;
} COMBO_ELEM, *PCOMBO_ELEM;

typedef struct GCOORDONNATE {
	int x, y;
} COORDONNATE, *PCOORDONNATE;

typedef struct GRECTANGLE {
	int x, y, w, h;
} GRECTANGLE, *PGRECTANGLE;

typedef struct GBORDER {
	int l, t, r, b;
} GBORDER, *PGBORDER;

typedef struct GCOLOR {
	int r, g, b;
} GCOLOR, *PGCOLOR;

typedef struct COMBO_INFO {
	GCOORDONNATE	box[4];
	GCOORDONNATE	list;
	GRECTANGLE	sbckTop, sbckMiddle, sbckBottom;
	GRECTANGLE	stmbTop, stmbMiddle, stmbBottom;
	GRECTANGLE	sbutTop[4];
	GRECTANGLE	sbutBottom[4];
	GBORDER		borderList;
	int		nBoxLeftSpace;
	GCOLOR		colorFont;
	GCOLOR		HighlightBckgrndColor;
	GCOLOR		HighlightForegrndColor;
	int		nFontSizeBox;
	int		nFontSizeList;
} COMBO_INFO, *PCOMBO_INFO;

class CGComboBox : public CGControl
{
public:
	CGComboBox( PEVENT_LIST pEventList, int nControlID, int nPosX, int nPosY, 
			int nWidth, int nHeight, int nOpenHeight, wxMemoryDC *pSkinMemDC, 
			wxMemoryDC *pSkinAlphaMemDC, PCOMBO_INFO pComboInfo );
	virtual ~CGComboBox(void);

	void	GetControlRect( int *nPosX, int *nPosY, int *nWidth, int *nHeight );
	bool	MouseEvent( int x, int y, int button, bool *bMouseOverCtrl, PREFRESH_RECT pRefreshRect );
	void	Enable( bool bEnable );
	void	ResetContent( void );
	void	AddString( const char *szString );
	void	SetCurSel( int nCurSel );
	int	GetCurSel( void );
	int	GetComboSize( void );
	bool	IsComboOpen( void );
	void	CloseComboBox( void );
	void	Paint( wxDC *pDC, PREFRESH_RECT refreshRect );

protected:
	wxMemoryDC	*m_pSkinMemDC, *m_pSkinAlphaMemDC;
	int		 m_nElemCount;
	int		 m_nElemSelect;
	int		 m_nMouseElemSelect;
	int		 m_nOpenHeight;
	int		 m_nComboBoxState;
	COMBO_INFO	 m_comboInfo;
	PCOMBO_ELEM	 m_pComboList;
	bool		 m_bComboOpen;
	int		 m_nTopButtonState, m_nBottomButtonState;
	int		 m_nTextHeightInBox, m_nTextHeightInList;
	int		 m_nStartPosInListBox, m_nStartPosInListBoxSaved;
	int		 m_nScrollBarZoneWidth;
	int		 m_nVisibleElemCount;
	bool		 m_bHScrollBar;
	int		 m_nThumbZoneSize;
};

#endif

