/////////////////////////////////////////////////////////////////////////////
// Name:        gcontrol.cpp
// Purpose:     GUI base control implementation using wxWidgets.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     02/25/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "gcontrol.h"


CGControl::CGControl( PEVENT_LIST pEventList, int nControlID, int nType, int nPosX, int nPosY, 
					  int nWidth, int nHeight )
{
	m_nType = nType;
	m_nPosX = nPosX;
	m_nPosY = nPosY;
	m_nWidth = nWidth;
	m_nHeight = nHeight;
	m_bEnable = true;
	m_bHide = false;
	m_pEventList = pEventList;
	m_nControlID = nControlID;
	strcpy(m_szTTText, "");
	m_nTTWidth = -1;
	m_ulTTDelayShow = 0;
	m_ulTTDelayHide = 0;
}

CGControl::~CGControl()
{
}

// ---------------------------------------------------------------------------
// Function: GetType
//
// Return control type (button, slider, checkbox, ...).
// ---------------------------------------------------------------------------
int CGControl::GetType()
{
	return m_nType;
}

// ---------------------------------------------------------------------------
// Function: SetPos
// ---------------------------------------------------------------------------
void CGControl::SetPos(int nPosX, int nPosY)
{
	m_nPosX = nPosX;
	m_nPosY = nPosY;
}

// ---------------------------------------------------------------------------
// Function: SetSize
// ---------------------------------------------------------------------------
void CGControl::SetSize(int nWidth, int nHeight)
{
	m_nWidth = nWidth;
	m_nHeight = nHeight;
}

// ---------------------------------------------------------------------------
// Function: GetControlRect
//
// Return control position and size.
// ---------------------------------------------------------------------------
void CGControl::GetControlRect( int *nPosX, int *nPosY, int *nWidth, int *nHeight )
{
	*nPosX = m_nPosX;
	*nPosY = m_nPosY;
	*nWidth = m_nWidth;
	*nHeight = m_nHeight;
}

// ---------------------------------------------------------------------------
// Function: MouseEvent
//
// Determine if the mouse cursor (x,y) is inside the control region.
// ---------------------------------------------------------------------------
bool CGControl::MouseEvent( int x, int y, int button, bool *bMouseOverCtrl, 
						   PREFRESH_RECT pRefreshRect )
{
	if (bMouseOverCtrl!=NULL)
		*bMouseOverCtrl = ((x>=m_nPosX && x<m_nPosX+m_nWidth) && (y>=m_nPosY && y<m_nPosY+m_nHeight));
	return false;
}

// ---------------------------------------------------------------------------
// Function: Enable
// ---------------------------------------------------------------------------
void CGControl::Enable( bool bEnable )
{
	m_bEnable = bEnable;
}

// ---------------------------------------------------------------------------
// Function: Hide
// ---------------------------------------------------------------------------
void CGControl::Hide( bool bHide )
{
	m_bHide = bHide;
}

// ---------------------------------------------------------------------------
// Function: IsEnable
// ---------------------------------------------------------------------------
bool CGControl::IsEnable( void )
{
	return m_bEnable;
}

// ---------------------------------------------------------------------------
// Function: IsHide
// ---------------------------------------------------------------------------
bool CGControl::IsHide( void )
{
	return m_bHide;
}

// ---------------------------------------------------------------------------
// Function: SetEvent
//
// Queue new event in the circular buffer which is own by the dialog box.
// ---------------------------------------------------------------------------
bool CGControl::SetEvent( int nMsg, unsigned long ulParam1, unsigned long ulParam2 )
{
	if (((m_pEventList->nIndexWrite+1)%m_pEventList->nMaxCount)==m_pEventList->nIndexRead) {
		// Event list is full!
		return false;
	}
	m_pEventList->pEventList[m_pEventList->nIndexWrite].nControlID = m_nControlID;
	m_pEventList->pEventList[m_pEventList->nIndexWrite].nMsg = nMsg;
	m_pEventList->pEventList[m_pEventList->nIndexWrite].ulParam1 = ulParam1;
	m_pEventList->pEventList[m_pEventList->nIndexWrite].ulParam2 = ulParam2;

	m_pEventList->nIndexWrite = (m_pEventList->nIndexWrite+1)%m_pEventList->nMaxCount;
	return true;
}

// ---------------------------------------------------------------------------
// Function: AddToolTips
//
// Set tooltips parameters.
// ---------------------------------------------------------------------------
void CGControl::AddToolTips( const char *szText, int nWidth, unsigned long ulDelayShow,
					unsigned long ulDelayHide )
{
	strcpy(m_szTTText, szText);
	m_nTTWidth = nWidth;
	m_ulTTDelayShow = ulDelayShow;
	m_ulTTDelayHide = ulDelayHide;
}

// ---------------------------------------------------------------------------
// Function: GetToolTips
//
// Get tooltips parameters.
// ---------------------------------------------------------------------------
void CGControl::GetToolTips( char *szText, int *nWidth, unsigned long *ulDelayShow, 
					unsigned long *ulDelayHide )
{
	strcpy(szText, m_szTTText);
	*nWidth = m_nTTWidth;
	*ulDelayShow = m_ulTTDelayShow;
	*ulDelayHide = m_ulTTDelayHide;
}


