/////////////////////////////////////////////////////////////////////////////
// Name:        gdialog.h
// Purpose:     GUI base Dialog implementation using wxWidgets.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     02/15/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "wx/wx.h" 
#include "gstatictext.h"
#include "gstatic.h"
#include "gbutton.h"
#include "gcheckbox.h"
#include "gslider.h"
#include "gcombobox.h"
#include "ghelpers.h"
#include "commondefs.h"
#include "dmanager.h"

#ifndef _GUILLEMOT_DIALOG_H_
#define _GUILLEMOT_DIALOG_H_

typedef struct CONTROL_LIST {
	CGControl	*pControl;
	CONTROL_LIST	*pNext;
} CONTROL_LIST, *PCONTROL_LIST;


class CGDialog
{
public:
	CGDialog( wxMemoryDC *pSkinMemDC, wxMemoryDC *pSkinAlphaMemDC, int nWidth, int nHeight );
	virtual ~CGDialog();

	int	 GetDelayForNextToolTipsEvent( void );
	void 	 PaintToolTips( wxDC *pDC );
	void 	 GetSize( int *nWidth, int *nHeight );
	virtual void InitializeDlgState( DJ_DEVICE_STATE *pDeviceState, CDManager *pDeviceManager );
	virtual void InitializeMixerState( DJ_DEVICE_STATE *pDeviceState, CDManager *pDeviceManager ) { }
	virtual	void InitializeHIDState( DJ_DEVICE_STATE *pDeviceState, CDManager *pDeviceManager ) { }
	virtual bool MouseEvent( int x, int y, int button, PREFRESH_RECT refreshRect );
	virtual bool ApplyVolume( DJ_DEVICE_STATE *pDeviceState ) { return false; }

	// --- Pure Virtual Functions ---
	virtual void Paint( wxDC *pDC, PREFRESH_RECT refreshRect );

	// --- Virtual Functions ---
	virtual bool SetTab( int nTab );

protected:
	int ConvertBCDtoInt( int nBCD );
	bool AddControl( CGControl *pCtrl );
	CGControl *GetControl( int nControlIDC );
	bool GetEvent( int *nControlID, int *nMsg, unsigned long *ulParam1, unsigned long *ulParam2 );

	// --- Variables ---
	int		 m_nWidth, m_nHeight;
	int		 m_nTab;
	CDManager	*m_pDManager;
	DJ_DEVICE_STATE	*m_pDeviceState;
	wxMemoryDC	*m_pSkinMemDC;		// Skin Source.
	wxMemoryDC	*m_pSkinAlphaMemDC;	// Skin Alpha Source.
	wxBitmap	 m_memDCBitmap;		// Bitmap used to store pixel.
	wxMemoryDC	 m_memDC;		// Memory DC Reserved to paint on it before painting on the real surface.
	EVENT_LIST	 m_eventList;
	GHelpers	 m_helpers;
	int		 m_nToolTipsWidth, m_nTTPosX, m_nTTPosY;
	int		 m_nToolTipsEventDelay;
	CGControl	*m_pTTCtrl;
	unsigned long	 m_ulTTTimeStart, m_ulTTDelayShow, m_ulTTDelayHide;

	PCONTROL_LIST	 m_pCtrlLstHead;	// Control List Head.
	PCONTROL_LIST	 m_pComboLstHead;	// Combo Box List Head.

private:

};

#endif

