/////////////////////////////////////////////////////////////////////////////
// Name:        gstatic.cpp
// Purpose:     GUI static image implementation using wxWidgets.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     02/26/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "gstatic.h"

CGStatic::CGStatic( PEVENT_LIST pEventList, int nControlID, int nPosX, int nPosY, 
			int nWidth, int nHeight, wxMemoryDC *pSkinMemDC, wxMemoryDC *pSkinAlphaMemDC, 
			int nStateCount, PSTATIC_STATE_INFO pStateInfo ) : 
		CGControl(pEventList, nControlID, GCONTROL_TYPE_STATIC_IMAGE, nPosX, nPosY, nWidth, nHeight)
{
	int i;

	m_pSkinMemDC = pSkinMemDC;
	m_pSkinAlphaMemDC = pSkinAlphaMemDC;
	m_nStateCount = nStateCount;
	m_pStateInfo = NULL;
	if (m_nStateCount>0) { 
		m_pStateInfo = new STATIC_STATE_INFO[m_nStateCount];
		for(i=0;i<m_nStateCount;++i) {
			m_pStateInfo[i].x = pStateInfo[i].x;
			m_pStateInfo[i].y = pStateInfo[i].y;
			m_pStateInfo[i].nProcessAlpha = pStateInfo[i].nProcessAlpha;
		}
	}
	m_nCurrentState = 0;
}

CGStatic::~CGStatic()
{
	if (m_pStateInfo!=NULL)
		delete m_pStateInfo;
	m_pStateInfo = NULL;
	m_pSkinMemDC = NULL;
	m_nStateCount = 0;
	m_nCurrentState = 0;
}

// ---------------------------------------------------------------------------
// Function: GetState
// ---------------------------------------------------------------------------
int CGStatic::GetState()
{
	return m_nCurrentState;
}

// ---------------------------------------------------------------------------
// Function: SetState
// ---------------------------------------------------------------------------
void CGStatic::SetState(int nState)
{
	if (nState>=0 && nState<m_nStateCount)
		m_nCurrentState = nState;
}

// ---------------------------------------------------------------------------
// Function: Paint
//
// Draw the static image base on its current state.
// ---------------------------------------------------------------------------
void CGStatic::Paint( wxDC *pDC, PREFRESH_RECT refreshRect )
{
	int	x, y, w, h;
	if (m_bHide || pDC==NULL || m_pSkinMemDC==NULL || m_pStateInfo==NULL || m_nCurrentState>=m_nStateCount)
		return;

	// --- If button is outside of the region, do not refresh it ---
	if (refreshRect->x>m_nPosX+m_nWidth || refreshRect->x+refreshRect->w<m_nPosX)
		return;
	if (refreshRect->y>m_nPosY+m_nHeight || refreshRect->y+refreshRect->h<m_nPosY)
		return;

	x=y=w=h=0;
	x = refreshRect->x - m_nPosX; if (x<0) x = 0;
	y = refreshRect->y - m_nPosY; if (y<0) y = 0;
	w = (m_nWidth-x) - refreshRect->w; if (w<0) w = 0;
	h = (m_nHeight-y) - refreshRect->h; if (h<0) h = 0;

	// --- Paint with or without transparency (stored in the .PNG file) ---
	if (m_pStateInfo[m_nCurrentState].nProcessAlpha) {
		pDC->Blit(m_nPosX+x, m_nPosY+y, m_nWidth-x-w, m_nHeight-y-h, m_pSkinAlphaMemDC, 
			m_pStateInfo[m_nCurrentState].x+x, m_pStateInfo[m_nCurrentState].y+y, wxAND);
		pDC->Blit(m_nPosX+x, m_nPosY+y, m_nWidth-x-w, m_nHeight-y-h, m_pSkinMemDC, 
			m_pStateInfo[m_nCurrentState].x+x, m_pStateInfo[m_nCurrentState].y+y, wxOR);
	}
	else
	{
		pDC->Blit(m_nPosX+x, m_nPosY+y, m_nWidth-x-w, m_nHeight-y-h, m_pSkinMemDC, 
			m_pStateInfo[m_nCurrentState].x+x, m_pStateInfo[m_nCurrentState].y+y, wxCOPY);
	}
}


