/////////////////////////////////////////////////////////////////////////////
// Name:        gstatictext.cpp
// Purpose:     GUI static text implementation using wxWidgets.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     02/25/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "gstatictext.h"

CGStaticText::CGStaticText( PEVENT_LIST pEventList, int nControlID, const char *szLabel, 
			int nPosX, int nPosY, int nWidth, int nHeight, unsigned long ulAlign ) :
	CGControl(pEventList, nControlID, GCONTROL_TYPE_STATIC_TEXT, nPosX, nPosY, nWidth, nHeight)
{
	strncpy(m_szLabel, szLabel, 511);
	strcpy(m_szFontName, "");
	m_nFontSize = 7;
	m_nFontRed = 0;
	m_nFontGreen = 0;
	m_nFontBlue = 0;
	m_nFontBold = 0;
	m_nFontItalic = 0;
	m_ulAlign = ulAlign;
	m_nDisableFontRed = 0;
	m_nDisableFontGreen = 0;
	m_nDisableFontBlue = 0;
}

CGStaticText::~CGStaticText()
{
}


// ---------------------------------------------------------------------------
// Function: SetFontSize
// ---------------------------------------------------------------------------
void CGStaticText::SetFontSize( int nSize )
{
	m_nFontSize = nSize;
}

// ---------------------------------------------------------------------------
// Function: SetFontColor
// ---------------------------------------------------------------------------
void CGStaticText::SetFontColor( int red, int green, int blue )
{
	m_nFontRed = red;
	m_nFontGreen = green;
	m_nFontBlue = blue;
}

// ---------------------------------------------------------------------------
// Function: SetDisableFontColor
// ---------------------------------------------------------------------------
void CGStaticText::SetDisableFontColor( int red, int green, int blue )
{
	m_nDisableFontRed = red;
	m_nDisableFontGreen = green;
	m_nDisableFontBlue = blue;
}

// ---------------------------------------------------------------------------
// Function: SetFontAttributes
// ---------------------------------------------------------------------------
void CGStaticText::SetFontAttributes( int nBold, int nItalic )
{
	m_nFontBold = nBold;
	m_nFontItalic = nItalic;
}

// ---------------------------------------------------------------------------
// Function: SetFontName
// ---------------------------------------------------------------------------
void CGStaticText::SetFontName( char *strFontName )
{
	strcpy(m_szFontName, strFontName);
}

// ---------------------------------------------------------------------------
// Function: SetLabel
// ---------------------------------------------------------------------------
void CGStaticText::SetLabel(char *szLabel)
{
	strncpy(m_szLabel, szLabel, 511);
}

// ---------------------------------------------------------------------------
// Function: GetLabel
// ---------------------------------------------------------------------------
int CGStaticText::GetLabel(char *szLabel)
{
	if (szLabel!=NULL)
		strcpy(szLabel, m_szLabel);
	return (int) strlen(m_szLabel);
}

// ---------------------------------------------------------------------------
// Function: Paint
//
// Draw text base with its attributes.
// ---------------------------------------------------------------------------
void CGStaticText::Paint( wxDC *pDC, PREFRESH_RECT refreshRect )
{
	wxFont	font(m_nFontSize, wxFONTFAMILY_DEFAULT, 
		(m_nFontItalic) ? wxFONTSTYLE_ITALIC : wxFONTSTYLE_NORMAL, 
		(m_nFontBold) ? wxFONTWEIGHT_BOLD : wxFONTWEIGHT_NORMAL);
	wxColor foregrndColor(m_nFontRed, m_nFontGreen, m_nFontBlue, wxALPHA_OPAQUE);
	wxColor foregrndDisableColor(m_nDisableFontRed, m_nDisableFontGreen, m_nDisableFontBlue, wxALPHA_OPAQUE);
	wxSize	size;
	int	tx, ty, tw, th;	// Coordinate of image (ix,iy), text (tx,ty), text (width,height)

	if (m_bHide || pDC==NULL) return;

	// --- If button is outside of the region, do not refresh it ---
	if (refreshRect->x>m_nPosX+m_nWidth || refreshRect->x+refreshRect->w<m_nPosX)
		return;
	if (refreshRect->y>m_nPosY+m_nHeight || refreshRect->y+refreshRect->h<m_nPosY)
		return;

	if (strlen(m_szFontName)>0)
		font.SetFaceName(m_szFontName);
	pDC->SetFont(font);

	size = pDC->GetTextExtent(m_szLabel);
	tw = size.GetWidth();
	th = size.GetHeight();

	// --- Align Horizontal ---
	if ((m_ulAlign&ALIGN_MASK)==ALIGN_LEFT)
		tx = m_nPosX;
	else if ((m_ulAlign&ALIGN_MASK)==ALIGN_CENTER)
		tx = m_nPosX+(m_nWidth-tw)/2;
	else
		tx = m_nPosX + m_nWidth - tw;
	if (tx<m_nPosX) tx = m_nPosX;

	// --- Align Vertical ---
	if ((m_ulAlign&VALIGN_MASK)==VALIGN_TOP)
		ty = m_nPosY;
	else if ((m_ulAlign&VALIGN_MASK)==VALIGN_CENTER)
		ty = m_nPosY + (m_nHeight - th)/2;
	else
		ty = m_nPosY + m_nHeight - th;
	if (ty<m_nPosY) ty = m_nPosY;


	if (m_bEnable)
		pDC->SetTextForeground(foregrndColor);
	else
		pDC->SetTextForeground(foregrndDisableColor);

	pDC->DrawText(m_szLabel, tx, ty);
}


