/////////////////////////////////////////////////////////////////////////////
// Name:        localization.cpp
// Purpose:     Contain and return the text strings base on the user
//		language.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     22/10/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include <ctype.h>
#include <stdio.h>
#include <string.h>
#include "commondefs.h"
#include "localization.h"

CLocalization::CLocalization( void )
{
	// Default language: English.
	m_nLanguageID = LANGID_ENGLISH;
}

CLocalization::~CLocalization()
{
}

// ---------------------------------------------------------------------------
// Function: SetLanguageID
//
// Set the language internal identifier base on the language code (ISO 639-1)
// ---------------------------------------------------------------------------
bool CLocalization::SetLanguageID( char *szLanguageCode )
{
	char szCode[3];
	szCode[0] = toupper(szLanguageCode[0]);
	szCode[1] = toupper(szLanguageCode[1]);
	szCode[2] = '\0';

	if (strcmp(szCode, "EN")==0) {
		m_nLanguageID = LANGID_ENGLISH;
		DEBUG_PRINT("Language set to ENGLISH.");
		return true;
	}
	else if (strcmp(szCode, "FR")==0) {
		m_nLanguageID = LANGID_FRENCH;
		DEBUG_PRINT("Language set to FRENCH.");
		return true;
	}
	else if (strcmp(szCode, "DE")==0) {
		m_nLanguageID = LANGID_GERMAN;
		DEBUG_PRINT("Language set to GERMAN.");
		return true;
	}
	else if (strcmp(szCode, "IT")==0) {
		m_nLanguageID = LANGID_ITALIAN;
		DEBUG_PRINT("Language set to ITALIAN.");
		return true;
	}
	else if (strcmp(szCode, "ES")==0) {
		m_nLanguageID = LANGID_SPANNISH;
		DEBUG_PRINT("Language set to SPANNISH.");
		return true;
	}
	else if (strcmp(szCode, "NL")==0) {
		m_nLanguageID = LANGID_DUTCH;
		DEBUG_PRINT("Language set to DUTCH.");
		return true;
	}

	return false;
}

// ---------------------------------------------------------------------------
// Function: GetString
//
// Return a pointer to the required string base on the user-language set via
// SetLanguageID.
// ---------------------------------------------------------------------------
const char *CLocalization::GetString( int nString_ID )
{
	static const char SZ_ENGLISH[][STRING_LENGTH] = {
		"http://ts.hercules.com/eng/",
		"http://ts.hercules.com/eng/index.php?pg=files_faq&gid=2&fid=28&pid=143", // DJ Console
		"http://ts.hercules.com/eng/index.php?pg=files_faq&gid=2&fid=28&pid=177", // Mk2
		"http://ts.hercules.com/eng/index.php?pg=files_faq&gid=2&fid=28&pid=179", // MP3
		"http://ts.hercules.com/eng/index.php?pg=files_faq&gid=2&fid=28&pid=215", // Rmx
		"http://ts.hercules.com/eng/index.php?pg=files_faq&gid=2&fid=28&pid=226", // Steel
		"(C) 2008-2009 Guillemot Corporation S.A.", "This program is free software.",
		"(Default)", "OK", "Normal", "DJ",
		"Master\nVolume", "Master", "Monitor", "Aux.",
		"MIDI Input:", "Recording Input:",
		"Package:", "Driver:", "Firmware:", "Bulk Status:", "Control Panel:",
		"MIDI channel:", "Talkover Attenuation:", "TALKOVER ATTENUATION",
		"Enable DJ mouse", "ENABLE DJ MOUSE", 
		"Line In", "Mic", "Digital (Coaxial)", "Digital (Optical)",
		"MIDI-In Plug",	"DJ Console buttons", 
		"Hercules DJ Console(tm) product is an integrated",
		"USB sound card and a DJ controller device.",
		"Hercules DJ Console(tm) version", "Hercules DJ Series Control Panel",
		"Please plug your Hercules DJ product.",
		"USB streaming 1-2 (Default)", "USB streaming 1-2 + Microphone", "USB streaming 1-2 + Line In 1-2",
		"MAIN",	"ADVANCED", "ABOUT", "OUTPUT CHANNELS", "INPUT CHANNELS",
		"JOG WHEELS SETTINGS", "CROSS FADER SETTINGS", "USE EXTERNAL MIXER",
		"Enabling/Disabling", "Sensitivity", "Output 1-2 Hardware mix option", "MIDI Channel for controls",
		"Please have this information ready when you", "contact our technical support team.",
		"Set the jog wheel sensitivity for both decks.",
		"Normal (Default)", "Less Sensitive", "Least Sensitive",
		"Enable (Default)", "Disable Jog Wheel on Deck A",
		"Disable Jog Wheel on Deck B", "Disable both Jog Wheels",
		"BeatMix Curve (Default)", "Dipped Curve", "Scratch Curve",
		"Lock on Deck A", "Lock on Deck B", "Lock on Center",
		"Hardware volume control.", "Double-click to reset balance in the center position.",
		"Normal:\nMix, play music, games and DVDs\n\nDJ:\nTalkover and headphone pre-listening for DJ Software",
		"Sample rate at 44.1 kHz or 48 kHz.", "Reduce music level while using microphone",
		"When this option is enabled, the left and right volume controls will follow each other.",
		"When an audio source is locked, the corresponding 'Audio source' button on the console is disabled.",
		"Inputs 1-2 recording selection: Microphone or Line/Phono Inputs 1-2.",
		"When enabled, your music mix will be attenuated by either 3, 6 or 9dB when the talkover function is enabled.",
		"Enable this option if you plan to use your DJ Console Mk2 with an external mixer: Deck A will then be routed to Outputs 1-2, and Deck B to Outputs 3-4. The cross fader is disabled when you enable this option.",
		"When you enable this option, the DJ Console Mk2's analog stick emulates a mouse.",
		"Displays the current audio source selection: either computer or external inputs (a turntable, for example). To switch modes, use the buttons labeled 'Audio source' on the DJ Console Mk2.",
		"Displays whether talkover mode is enabled or not. Press the microphone volume control/talkover button on the DJ Console Mk2's front face to toggle on or off.",
		"Displays the state of the 'Headphones Selection' knob located on the DJ Console Mk2's front face.",
		"This graph represents the volume of each deck according to the position of the cross fader.",
		"This  option allows you to set the cross fader state in specific positions. For example, lock the cross fader in the center position if you just want to use the volume sliders to mix your music.",
		"Set the MIDI channel from 1 to 16 on which data is sent and received for this device.",
		"Report bugs to <http://ts.hercules.com/eng/index.php?pg=email>.",
		"Usage:", "OPTION", "version", "physical location:",
		"Warning: language '%s' not supported!",
		"Warning: device %s not found!", "invalid option '%s'",
		"Try '%s %s' for more information.", "This program is free software;",
		"you can redistribute it and/or modify it under\nthe terms of the GNU General Public License as published by the Free Software\nFoundation; either version 2 of the License, or (at your option)\nany later version",
		"This program is distributed in the hope that it will be useful, but\nWITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY\nor FITNESS FOR A PARTICULAR PURPOSE.\n\nSee the GNU General Public License for more details.",
		"Written by and/or for Guillemot Corporation S.A.", "same as %s",
		"Warning: process '%s' is already running.",
		"give this help", "output debug strings (syslog)",
		"set the current device physical location",
		"specify the user-language (en, fr, de, it, es, nl)",
		"display license and version number",
		"allow multiple instances of this application",
		"list detected devices with their physical location",
		"Contact: Guillemot Corporation S.A., BP2, 56204 La Gacilly Cedex, France or\n         <http://ts.hercules.com/eng/index.php?pg=email>.",
		};

	static const char SZ_FRENCH[][STRING_LENGTH] = {
		"http://ts.hercules.com/fr/",
		"http://ts.hercules.com/fr/index.php?pg=files_faq&gid=2&fid=28&pid=143", // DJ Console
		"http://ts.hercules.com/fr/index.php?pg=files_faq&gid=2&fid=28&pid=177", // Mk2
		"http://ts.hercules.com/fr/index.php?pg=files_faq&gid=2&fid=28&pid=179", // MP3
		"http://ts.hercules.com/fr/index.php?pg=files_faq&gid=2&fid=28&pid=215", // Rmx
		"http://ts.hercules.com/fr/index.php?pg=files_faq&gid=2&fid=28&pid=226", // Steel
		"(C) 2008-2009 Guillemot Corporation S.A.", "Ce logiciel est gratuit.",
		"(par défaut)", "OK", "Normal", "DJ",
		"Volume\nprincipal", "Master", "Monitor", "Aux.",
		"Source MIDI :", "Source d'enregistrement :",
		"Package :", "Pilote :", "Firmware :", "Statut général :", "Control Panel :",
		"Canal MIDI :", "Réduction du volume", "ATTÉNUATION TALKOVER",
		"Activer la souris DJ", "ACTIVER SOURIS DJ", 
		"Entrée Ligne", "Entrée Micro", "Numérique coaxial", "Numérique optique",
		"Connecteur MIDI-In", "Boutons DJ Console", 
		"Hercules DJ Console(tm) est une carte son",
		"USB intégrée et un contrôleur DJ.",
		"Hercules DJ Console(tm) version", "Hercules DJ Series Control Panel",
		"Veuillez brancher votre Hercules DJ.",
		"Streaming USB 1-2 (par défaut)", "Streaming USB 1-2 + Microphone", "Streaming USB 1-2 + Line In 1-2",
		"PRINCIPAL", "AVANCÉ", "A PROPOS", "CANAUX DE SORTIE", "CANAUX D'ENTRÉE",
		"REGLAGES DES JOG-WHEELS", "REGLAGES DU CROSSFADER", "UTILISER MIXER EXTERNE",
		"Activer/Désactiver", "Sensibilité", "Options de mix hardware sorties 1-2", "Canaux MIDI pour les commandes",
		"Veillez à vous munir de ces informations", "lorsque vous contactez notre support technique.",
		"Définir la sensibilité des jog-wheels pour les deux decks.",
		"Normal (par défaut)", "Moins sensible", "Le moins sensible",
		"Activer (par défaut)", "Désactiver le jog-wheel sur le Deck A",
		"Désactiver le jog-wheel sur le Deck B", "Désactiver les deux jog-wheels",
		"Courbe BeatMix (Défaut)", "Courbe Dipped", "Courbe Scratch",
		"Verrouiller sur Deck A", "Verrouiller sur Deck B", "Verrouiller au Centre",
		"Réglage du volume en hardware.", "Double-cliquez pour ramener le réglage\nde la balance en position neutre.",
		"Normal:\nPour écouter CD-Audio, MP3, jeux et DVD\n\nDJ:\nPré-écoute au casque dans les logiciels DJ",
		"Taux d’échantillonnage : 44,1 kHz ou 48 kHz.", "Réduire le niveau de la musique lorsque le micro est ouvert",
		"Lorsque cette option est activée, les commandes de volume gauche et droit sont solidaires.",
		"Lorsqu’une source audio est verrouillée,\nle bouton Audio source correspondant\nsur la console devient inopérant.",
		"Sélection de la source d’enregistrement sur\nles entrées 1-2: Line-in/Phono ou micro.",
		"Si cette fonction est activée, votre mix sera atténué\nde 3, 6 ou 9 dB lors de l’utilisation du Talkover.",
		"Activez cette option si vous décidez d’utiliser votre DJ Console Mk2\navec un mixeur externe : le Deck A sera dirigé vers les sorties 1-2\net le Deck B vers les sorties 3-4.\nLe cross-fader devient inopérant lorsque cette option est activée.",
		"Lorsque vous activez cette option, le stick analogique\nde la DJ Console Mk2 émule une souris.",
		"Affiche le type de source audio sélectionné : soit l’ordinateur,\nsoit une source externe (une platine par exemple).\n\nUtilisez les boutons Audio source sur votre DJ Console Mk2\npour basculer d’un type à l’autre.",
		"Indique si le mode Talkover est activé ou non.\n\nAppuyez sur le bouton Volume micro/Talkover\nen face avant de votre DJ Console Mk2 pour\nactiver/désactiver le mode Talkover.",
		"Affiche le statut du bouton Headphones Selection\nsitué en face avant de votre DJ Console Mk2.",
		"Ce graphique représente la courbe du volume de chaque\ndeck en fonction de la position du cross-fader.",
		"Cette option vous permet de définir des positions spécifiques pour le cross-fader.\nVous pouvez par exemple verrouiller le cross-fader en position centrale si vous\nvoulez mixer uniquement avec les glissières de volume.",
		"Définir un canal MIDI de 1 à 16 sur lequel les données sont envoyées et reçues pour cet appareil.",
		"Veuillez signaler les éventuels bugs à\n<http://ts.hercules.com/fr/index.php?pg=email>.",
		"Utilisation:", "OPTION", "version", "emplacement physique :",
		"Avertissements : langue %s non supportée !",
		"Avertissements : périphérique %s non détecté !", "option non valide %s",
		"Tapez '%s %s' pour plus d’informations.", "Ce logiciel est gratuit.",
		"Vous pouvez en redistribuer des copies dans le\nrespect des termes de la Licence publique générale GNU (GNU GPL).",
		"Aucune GARANTIE n’est fournie pour ce programme, dans la limite\nautorisée par la loi.",
		"Ecrit par et/ou pour Guillemot Corporation.", "identique à %s",
		"Avertissements : processus %s déjà en cours d’exécution.", "Afficher ce message d'aide",
		"Texte de débogage (syslog)", "Définir l’emplacement physique actuel du périphérique",
		"Indiquer la langue utilisateur (en, fr, de, it, es, nl)",
		"Afficher la licence et la version",
		"Permettre l’exécution de plusieurs sessions de l’application",
		"Liste des périphériques détectés avec emplacement physique",
		"Contact: Guillemot Corporation S.A., BP2, 56204 La Gacilly Cedex, France or\n         <http://ts.hercules.com/fr/index.php?pg=email>.",
		};

	static const char SZ_GERMAN[][STRING_LENGTH] = {
		"http://ts.hercules.com/ger/",
		"http://ts.hercules.com/ger/index.php?pg=files_faq&gid=2&fid=28&pid=143", // DJ Console
		"http://ts.hercules.com/ger/index.php?pg=files_faq&gid=2&fid=28&pid=177", // Mk2
		"http://ts.hercules.com/ger/index.php?pg=files_faq&gid=2&fid=28&pid=179", // MP3
		"http://ts.hercules.com/ger/index.php?pg=files_faq&gid=2&fid=28&pid=215", // Rmx
		"http://ts.hercules.com/ger/index.php?pg=files_faq&gid=2&fid=28&pid=226", // Steel
		"(C) 2008-2009 Guillemot Corporation S.A.", "Dies ist freie Software.",
		"(Default)", "OK", "Normal", "DJ",
		"Master\nLautstärke", "Master", "Monitor", "Aux.",
		"MIDI-Eingang:", "Aufnahme-Eingang:",
		"Paket:", "Treiber:", "Firmware:", "Bulk Status:", "Control Panel:",
		"MIDI Kanal:", "Talkover-Absenkung:", "TALKOVER-ABSENKUNG",
		"DJ Mouse aktivieren", "DJ MOUSE AKTIVIEREN", 
		"Line-Eingang", "Mikrofon", "Digital (koaxial)", "Digital (optisch)",
		"MIDI-Eingangsbuchse", "DJ Console-Buttons", 
		"Die Hercules DJ Console(tm) ist eine integrierte",
		"USB Soundkarte und ein DJ Controller.",
		"Hercules DJ Console(tm) version", "Hercules DJ Series Control Panel",
		"Bitte schließen Sie Ihr Hercules DJ Produkt an.",
		"USB streaming 1-2 (Default)", "USB streaming 1-2 + Mikrophon", "USB streaming 1-2 + Line In 1-2",
		"MAIN",	"ERWEITERT", "ÜBER", "AUSGANGSKANÄLE", "EINGANGSKANÄLE",
		"JOG-WHEELS Einstellungen", "CROSSFADER Einstellungen", "EXTERNEN MIXER NUTZEN",
		"Aktivieren/Deaktivieren", "Empfindlichkeit", "Output 1-2 Hardwaremixoptionen", "MIDI Kanal für Kontrollen",
		"Bitte halten Sie diese Informationen bereit,", "wenn Sie den technischen Support kontaktieren.",
		"Jogwheelempfindlichkeit für beide Decks setzen.",
		"Normal (Default)", "Weniger Empfindlich", "Mindestempfindlichkeit",
		"Aktivieren (Standard)", "Jog-Wheel auf Deck A deaktivieren",
		"Jog-Wheel auf Deck B deaktivieren", "Beide Jog-Wheels deaktivieren",
		"BeatMix Charakteristik (Standard)", "Abgesenkte Charakteristik", "Scratch Charakteristik",
		"Auf Deck A verriegeln", "Auf Deck B verriegeln", "Auf Mitte verriegeln",
		"Hardware-Lautstärkeregler.", "Ein Doppelklick bringt die Balance\nin die Center-Position",
		"Normal:\nFür Multimedia-Anwendungen, Musik, Spiele und DVDs\n\nDJ:\nVorhören über Kopfhörer in DJ Programmen",
		"Samplerate bei 44.1 kHz oder 48 kHz.", "Reduzieren des Musiklevels während Mikrophonbenutzung",
		"Wenn diese Option aktiviert ist, sind die Einstellungen des rechten und linken Lautstärkereglers immer identisch.",
		"Wenn die Audioquelle verriegelt ist,\ndann ist der entsprechende Button\nauf der DJ Console wirkungslos.",
		"Eingänge 1-2 Aufnahmewahl: \nMikrofon oder Eingänge 1-2.",
		"Falls aktiviert wird Ihre Musikabmischung bei Aktivierung\nder Talkover-Funktion um 3, 6 oder 9dB abgesenkt.",
		"Aktivieren Sie diese Option, wenn Sie die DJ Console Mk2 mit einem\nexternen Mixer nutzen wollen: Deck A wird auf die Ausgänge 1-2 geroutet,\nund Deck B auf die Ausgänge 3-4.\nDer Crossfader wird in dieser Option deaktiviert.",
		"Wenn Sie diese Option aktivieren emuliert der\nanaloge Ministick der DJ Console Mk2 eine Maus.",
		"Zeigt die aktuelle Audioquellenwahl an: Entweder Computer\noder externe Eingänge (Plattenspieler beispielsweise).\n\nUm die Modi zu wechseln benutzen Sie bitte den Audio source\nButton auf der DJ Console Mk2.",
		"Zeigt an, ob der Talkover-Modus aktiviert ist oder nicht.\n\nDrücken Sie den Mikrofon-Lautstärke/Talkover-Regler auf der\nFront der DJ Console Mk2 um ihn zu aktivieren/deaktivieren.",
		"Zeigt den Status des Headphones Selection Drehschalters\nauf der Front der DJ Console Mk2 an.",
		"Die Kurve visualisiert die Lautstärke jedes Decks\nin Abhängigkeit der Crossfader-Position.",
		"Diese Option erlaubt es, den Crossfader in einer bestimmten Stellung zu verriegeln.\nFalls Sie beispielsweise beim Mix nur mit den Kanalfadern arbeiten wollen, können Sie\nden Crossfader in der mittleren Position sichern.",
		"Den MIDI-Kanal, von dem Daten für dieses Gerät gesendet und empfangen werden, von 1 bis 16 setzen.",
		"Bugs bitte berichten an:<http://ts.hercules.com/ger/index.php?pg=email>.",
		"Nutzung:", "OPTION", "Version", "Physischer Position:",
		"Warnung: Sprache %s nicht unterstützt!",
		"Warnung: Gerät %s nicht gefunden!", "Falsche Option %s",
		"Versuchen Sie '%s %s' für mehr Information.", "Dies ist freie Software.",
		"Sie können hiervon Kopien unter den Bedingungen\nder GNU General Public License (Namensnennungslizenz) verteilen.",
		"Im rechtlich zulässigen Umfang ist eine GARANTIE AUSGESCHLOSSEN.",
		"Erstellt von und/oder für Guillemot Corporation.", "gleichbedeutend wie %s",
		"Warnung: Prozeß %s wird bereits ausgeführt.", "Hilfe ausführen",
		"Ausgangs-Debug-Strings (syslog)", "Physische Position für aktuelles Gerät setzen",
		"Nutzersprache spezifizieren (en, fr, de, it, es, nl)",
		"Lizenz- und Versionsnummer",
		"Mehrere Ebenen dieser Applikation erlauben",
		"Erkannte Geräte mit physischer Position auflisten",
		"Contact: Guillemot Corporation S.A., BP2, 56204 La Gacilly Cedex, France or\n         <http://ts.hercules.com/ger/index.php?pg=email>.",
		};

	static const char SZ_ITALIAN[][STRING_LENGTH] = {
		"http://ts.hercules.com/it/",
		"http://ts.hercules.com/it/index.php?pg=files_faq&gid=2&fid=28&pid=143", // DJ Console
		"http://ts.hercules.com/it/index.php?pg=files_faq&gid=2&fid=28&pid=177", // Mk2
		"http://ts.hercules.com/it/index.php?pg=files_faq&gid=2&fid=28&pid=179", // MP3
		"http://ts.hercules.com/it/index.php?pg=files_faq&gid=2&fid=28&pid=215", // Rmx
		"http://ts.hercules.com/it/index.php?pg=files_faq&gid=2&fid=28&pid=226", // Steel
		"(C) 2008-2009 Guillemot Corporation S.A.", "Questo è un software gratuito.",
		"(predefinita)", "OK", "Normale", "DJ",
		"Volume\nprincipale", "Master", "Monitor", "Aux.",
		"Ingresso MIDI:", "Ingresso in registrazione:",
		"Pacchetto software:", "Driver:", "Firmware:", "Codice Bulk:", "Control Panel:",
		"Canale MIDI:", "Attenuazione Talkover:", "TALKOVER ATTENUAZIONE",
		"Attivare mouse DJ", "ATTIVA MOUSE DJ", 
		"Line In", "Microfono", "Digitale (Coassiale)", "Digitale (Ottico)",
		"Connessione MIDI-In",	"Pulsanti DJ Console", 
		"Il prodotto Hercules DJ Console(tm) è costituito da una",
		"scheda audio USB integrata e un controller per DJ.",
		"Hercules DJ Console(tm) version", "Hercules DJ Series Control Panel",
		"Per favore, collega il tuo prodotto Hercules DJ.",
		"USB streaming 1-2 (Predef.)", "USB streaming 1-2 + Microfono", "USB streaming 1-2 + Line In 1-2",
		"PRINCIPALE", "AVANZATE", "INFO SU", "CANALI IN USCITA", "INGRESSI",
		"Impostazioni MANOPOLE JOG", "Impostazioni CROSS FADER", "USA MIXER ESTERNO",
		"Attiva/Disattiva", "Sensibilità", "Opzioni mix hardware per uscite 1-2", "Canale MIDI per controlli",
		"Quando contatterai il nostro servizio di Assistenza", "Tecnica, tieni sotto mano le seguenti informazioni.",
		"Imposta la sensibilità della manopola jog per entrambi i banchi.",
		"Normale (predefinita)", "Meno sensibile", "Sensibilità al minimo",
		"Attiva (Default)", "Disattiva Manopola Jog per il Deck A",
		"Disattiva Manopola Jog per il Deck B", "Disattiva entrambe le Manopole Jog",
		"Curva BeatMix (Predefinito)", "Curva Dipped", "Curva Scratch",
		"Bloccare su Banco A", "Bloccare su Banco B", "Bloccare al Centro",
		"Controllo del volume dell’hardware.", "Fai doppio clic per ripristinare il\nbilanciamento in posizione centrale.",
		"Normale:\nPer riprodurre musica, per giochi e DVD\n\nDJ:\nAscolta nelle tue cuffie un brano diverso da quello diffuse in quel momento dagli altoparlanti",
		"Frequenza di campionamento a 44,1 kHz o 48 kHz.", "Riduce il volume della musica durante l'uso del microfono",
		"Quando questa funzione è attiva, i controlli destro e sinistro del volume risulteranno legati tra loro.",
		"Quando una sorgente audio viene bloccata,\nil corrispondente pulsante Audio source della\nconsole viene disabilitato.",
		"Seleziona la registrazione degli ingressi 1-2:\ningressi 1-2 o microfono.",
		"Muovendo l’indicatore, il volume del tuo mix musicale verrà attenuato\ndi 3, 6 o 9dB, qualora la funzione talkover sia attivata.",
		"Attiva questa opzione se desideri utilizzare la tua DJ Console Mk2 con un mixer esterno:\nil Banco A verrà indirizzato alle uscite 1-2 ed il Banco B alle uscite 3-4.\nse attivi questa opzione, il cross fader non sarà attivo.",
		"Se attivi questa opzione, lo stick analogico\ndi DJ Console Mk2 emulerà il mouse.",
		"Visualizza la sorgente audio attualmente selezionata: computer\noppure ingressi esterni (come un giradischi, ad esempio).\n\nPer passare tra le varie modalità, utilizza i pulsanti Audio source\ndi DJ Console Mk2.",
		"Visualizza lo stato della modalità talkover (attivata/disattivata).\n\nPer attivare/disattivare tale modalità, premi il pulsante del volume\ndel microfono/Talkover posto nella parte frontale di DJ Console Mk2.",
		"Visualizza lo stato della manopola Headphones Selection\nsituata nella parte frontale di DJ Console Mk2.",
		"Questo grafico visualizza il volume di ciascun banco\nrelativamente alla posizione del cross fader.",
		"Questa funzione ti permette di impostare il cross fader su posizioni particolari.\nAd esempio, puoi bloccare il cross fader in posizione centrale per utilizzare gli\nindicatori del volume per mixare la tua musica.",
		"Imposta il canale MIDI da 1 a 16 attraverso il quale i dati vengono inviati e ricevuti dalla periferica in questione.",
		"Segnalane i difetti a <http://ts.hercules.com/it/index.php?pg=email>.",
		"Uso:", "OPZIONE", "versione", "percorso fisico:",
		"Attenzione: lingua %s non supportata!",
		"Attenzione: periferica %s non trovata!", "opzione %s non valida",
		"Per ulteriori informazioni, digita '%s %s'.", "Questo è un software gratuito.",
		"Puoi ridistribuirne copie nel rispetto dei\ntermini indicati nella Licenza GNU per il Grande Pubblico.",
		"Negli estremi previsti dalla legge, non vi è ALCUNA GARANZIA.",
		"Scritto da e/o per Guillemot Corporation.", "stesso di %s",
		"Attenzione: il processo %s è già aperto.", "fornisce aiuto",
		"debug righe in uscita (syslog)", "imposta la posizione fisica attuale della periferica",
		"specifica il linguaggio utente (en, fr, de, it, es, nl)",
		"licenza e numero della versione",
		"permette più istanze di questa applicazione",
		"elenco periferiche individuate e relativa posizione fisica",
		"Contact: Guillemot Corporation S.A., BP2, 56204 La Gacilly Cedex, France or\n         <http://ts.hercules.com/it/index.php?pg=email>.",
		};

	static const char SZ_SPANNISH[][STRING_LENGTH] = {
		"http://ts.hercules.com/es/",
		"http://ts.hercules.com/es/index.php?pg=files_faq&gid=2&fid=28&pid=143", // DJ Console
		"http://ts.hercules.com/es/index.php?pg=files_faq&gid=2&fid=28&pid=177", // Mk2
		"http://ts.hercules.com/es/index.php?pg=files_faq&gid=2&fid=28&pid=179", // MP3
		"http://ts.hercules.com/es/index.php?pg=files_faq&gid=2&fid=28&pid=215", // Rmx
		"http://ts.hercules.com/es/index.php?pg=files_faq&gid=2&fid=28&pid=226", // Steel
		"(C) 2008-2009 Guillemot Corporation S.A.", "Este software es gratuito.",
		"(Predeterminada)", "Aceptar", "Normal", "DJ",
		"Master\nVolumen", "Master", "Monitor", "Aux.",
		"Entrada MIDI:", "Entrada de grabación:",
		"Paquete:", "Controlador:", "Firmware:", "Estado general:", "Control Panel:",
		"Canal MIDI:", "Atenuación de Talkover:", "ATENUACIÓN TALKOVER",
		"Activar DJ mouse", "ACTIVAR DJ MOUSE", 
		"Line In", "Mic", "Digital (Coaxial)", "Digital (Óptica)",
		"Conector MIDI-In", "Botones de DJ Console", 
		"El producto Hercules DJ Console(tm) es una tarjeta de",
		"sonido USB integrada y un dispositivo controlador de DJ.",
		"Hercules DJ Console(tm) version", "Hercules DJ Series Control Panel",
		"Conecta tu producto de Hercules DJ.",
		"USB streaming 1-2 (Predeterm.)", "USB streaming 1-2 + Micrófono", "USB streaming 1-2 + Line In 1-2",
		"PRINCIPAL", "AVANZADO", "ACERCA DE", "Canales de Salida", "Canales de Entrada",
		"CONFIGURACIÓN DE JOG WHEELS", "CONFIGURACIÓN DE CROSS FADER", "MEZCLADOR EXTERNO",
		"Habilitar/Deshabilitar", "Sensibilidad", "Opciones mezcla salida 1-2", "Canal MIDI para controles",
		"Ten preparada esta información cuando contactes", "con nuestro equipo de servicio técnico.",
		"Establece la sensibilidad de la jog wheel para ambos decks.",
		"Normal (Predeterminada)", "Menos sensible", "Sensible al mínimo",
		"Activar (Predeterminado)", "Desactivar Jog Wheel del plato A",
		"Desactivar Jog Wheel del plato B", "Desactivar ambas Jog Wheels",
		"Curva de beatMix (Por defecto)", "Curva con descenso", "Curva de scratch",
		"Bloqueo en Deck A", "Bloqueo en Deck B", "Bloqueo en Centro",
		"Control de volumen por hardware.", "Haz doble clic para restablecer el\nbalance en la posición central.",
		"Normal:\nOír música, juegos y DVD\n\nDJ:\nEscucha en tus auriculares otra música distinta a la de los archivos de audio reproducidos para la audiencia",
		"Frecuencia de muestreo a 44,1 kHz o 48 kHz.", "Reducir nivel de la música al utilizar el micrófono",
		"Cuando esta opción está habilitada, lo controles de volumen izquierdo y derecho se siguen.",
		"Cuando una fuente de audio está bloqueada,\nel botón Audio source correspondiente  en la\nconsola está desactivado.",
		"Selección de grabación de entradas 1-2:\nEntradas 1-2 o micrófono.",
		"Si está activado, tu mezcla musical será atenuada en\n3, 6 o 9 dB cuando se active la función de talkover.",
		"Activa  esta  opción  si  tienes  pensado  utilizar  DJ Console Mk2\ncon un mezclador externo: el plato A se dirigirá a las Salidas 1-2,\ny el plato B a las Salidas 3-4.\nEl cross fader está desactivado cuando activas esta opción.",
		"Cuando activas esta opción, el stick analógico\nde DJ Console Mk2 emula a un ratón.",
		"Muestra la selección de origen de audio actual: ordenador\no entradas externas (un giradiscos, por ejemplo).\n\nPara cambiar modos, utiliza los botones etiquetados como\nAudio source en DJ Console Mk2.",
		"Muestra  si  el  modo talkover está activado o no.\n\nPulsa el control de volumen  del  micrófono/botón\nde Talkover en la cara frontal de DJ Console Mk2\npara activarlo o desactivarlo.",
		"Muestra el estado de la rueda Headphones Selection\nsituada en la cara frontal de DJ Console Mk2.",
		"Este gráfico representa el volumen de cada\nplato según la posición del cross fader.",
		"Esta opción te permite colocar el estado del cross fader en posiciones específicas.\nPor ejemplo, bloquea el cross fader en la posición central si sólo quieres utilizar los\ndeslizadores de volumen para mezclar la música.",
		"Definir el canal MIDI de 1 a 16 por el que se envían y se reciben datos de este dispositivo.",
		"Informar de errores en <http://ts.hercules.com/es/index.php?pg=email>.",
		"Uso:", "OPCIÓN", "versión", "ubicación física:",
		"Aviso: ¡idioma %s no admitido!",
		"Aviso: ¡no se ha encontrado el dispositivo %s!", "opción no válida %s",
		"Escribe '%s %s' para obtener más información.", "Este software es gratuito.",
		"Puedes redistribuir copias de él bajo las\ncondiciones de la licencia GNU General Public License.",
		"NO incluye ninguna GARANTÍA, hasta el límite permitido por la ley.",
		"Escrito por y/o para Guillemot Corporation.", "igual que %s",
		"Aviso: el proceso %s ya se está ejecutando.", "entregar esta ayuda",
		"salida de cadenas de depuración (syslog)", "definir la ubicación física del dispositivo actual",
		"especificar el idioma del usuario (en, fr, de, it, es, nl)",
		"mostrar licencia y número de versión",
		"permitir varias instancias de esta aplicación",
		"enumerar dispositivos detectados con su ubicación física",
		"Contact: Guillemot Corporation S.A., BP2, 56204 La Gacilly Cedex, France or\n         <http://ts.hercules.com/es/index.php?pg=email>.",
		};

	static const char SZ_DUTCH[][STRING_LENGTH] = {
		"http://ts.hercules.com/nl/",
		"http://ts.hercules.com/nl/index.php?pg=files_faq&gid=2&fid=28&pid=143", // DJ Console
		"http://ts.hercules.com/nl/index.php?pg=files_faq&gid=2&fid=28&pid=177", // Mk2
		"http://ts.hercules.com/nl/index.php?pg=files_faq&gid=2&fid=28&pid=179", // MP3
		"http://ts.hercules.com/nl/index.php?pg=files_faq&gid=2&fid=28&pid=215", // Rmx
		"http://ts.hercules.com/nl/index.php?pg=files_faq&gid=2&fid=28&pid=226", // Steel
		"(C) 2008-2009 Guillemot Corporation S.A.", "Dit is vrije software.",
		"(standaard)", "OK", "Normaal", "DJ",
		"Master\nVolume", "Master", "Monitor", "Aux.",
		"MIDI-ingang:", "Opname-ingang:",
		"Package:", "Driver:", "Firmware:", "Bulkstatus:", "Control Panel:",
		"MIDI-kanaal:", "Talkover-demping:", "TALKOVER-ABSENKUNG",
		"DJ mouse selecteren", "DJ MOUSE INSCHAKELEN", 
		"Line In", "Mic", "Digitaal (coax)", "Digitaal (optisch)",
		"Apparaat op MIDI-In", "Knoppen DJ Console", 
		"Hercules DJ Console(tm) is een USB-geluidskaart",
		"en DJ-besturingsapparaat in één.",
		"Hercules DJ Console(tm) version", "Hercules DJ Series Control Panel",
		"Sluit uw Hercules DJ-product aan.",
		"USB streaming 1-2 (Standaard)", "USB streaming 1-2 + Microphone", "USB streaming 1-2 + Line In 1-2",
		"HOOFD", "GEAVANCEERD", "INFO", "UITGANGSKANALEN", "INGANGSKANALEN",
		"INSTELLINGEN JOG-WIELEN", "INSTELLINGEN CROSSFADER", "EXTERN MENGPANEEL",
		"In-/uitschakelen", "Gevoeligheid", "Uitgang 1-2 hardwaremengopties", "MIDI-kanaal voor besturing",
		"Deze informatie heeft u nodig wanneer u", "contact opneemt met onze technical support.",
		"De gevoeligheid van het jog-wiel instellen voor beide decks.",
		"Normaal (standaard)", "Minder gevoelig", "Minst gevoelig",
		"Inschakelen (standaard)", "Jog-wiel op deck A uitschakelen",
		"Jog-wiel op deck B uitschakelen", "Beide jog-wielen uitschakelen",
		"BeatMix-curve (standaard)", "Dipped-curve", "Scratch-curve",
		"Vergrendelen op Deck A", "Vergrendelen op Deck B", "Vergrendelen op midden",
		"Hardwarematige volumeregeling", "Dubbelklik om de balans in\nmiddenstand terug te zetten.",
		"Normaal:\nHet afspelen van muziek, games en DVD's\n\nDJ:\nBeluister over de koptelefoon andere muziek dan de audiobestanden die voor het publiek worden afgespeeld",
		"Sample-frequentie is 44,1 of 48 kHz.", "Muziek zachter bij gebruik microfoon",
		"Wanneer deze optie is ingeshakeld, volgen de linker en rechter volumeregelingen elkaar.",
		"Wanneer een audiobron is vergrendeld,\nis de knop voor de betreffende audiobron\nop de console uitgeschakeld.",
		"Selecteren van de opname voor ingangen 1-2:\ningangen 1-2 of microfoon.",
		"Wanneer ingeschakeld, wordt de muziekmix met 3, 6 of 9 dB\ngedempt als de talkover-functie is ingeschakeld.",
		"Schakel deze optie in als u uw DJ Console Mk2 wilt gebruiken met een extern mengpaneel:\nDeck A wordt dan naar de uitgangen 1-2 gestuurd en Deck B naar de uitgangen 3-4.\nDe crossfader wordt uitgeschakeld als u deze optie inschakelt.",
		"Wanneer u deze optie inschakelt, emuleert de\nanaloge stick van de DJ Console Mk2 een muis.",
		"Aanduiding van de geselecteerde audiobron: computer\nof externe ingangen (bijvoorbeeld een draaitafel).\n\nKies een andere bron met behulp van de knoppen\nAudio source op de DJ Console Mk2.",
		"Aanduiding of talkover-modus al of niet is ingeschakeld.\n\nDruk op de knop microfoonvolume/Talkover op de voorkant\nvan de DJ Console Mk2 om deze modus in of uit te schakelen.",
		"Aanduiding van de status van de knop Headphones Selection\nop de voorkant van de DJ Console Mk2.",
		"Deze grafiek geeft het volume aan van elk\ndeck volgens de stand van de crossfader.",
		"Met deze optie zet u de crossfader in de gewenste positie. Vergrendel\nbijvoorbeeld de crossfader in de middenstand als u de volumeschuifregelaars\nwilt gebruiken voor het mixen van uw muziek.",
		"Het MIDI-kanaal waarop gegevens voor dit apparaat worden ontvangen en verzonden, instellen op 1 tot 16.",
		"Bugs melden aan <http://ts.hercules.com/nl/index.php?pg=email>.",
		"Gebruik", "OPTIE", "versie", "fysieke locatie:",
		"Waarschuwingen: taal %s niet ondersteund.",
		"Waarschuwingen: apparaat %s niet gevonden.", "ongeldige optie %s",
		"Probeer '%s %s' voor meer informatie.", "Dit is vrije software.",
		"U mag kopiën verspreiden onder de voorwaarden\nvan de GNU General Public License.",
		"Er wordt GEEN GARANTIE verleend, in zoverre de wet dit toestaat.",
		"Geschreven door en/of voor Guillemot Corporation.", "identiek aan %s",
		"Waarschuwingen: proces %s wordt al uitgevoerd.", "geef deze hulp",
		"output debug-strings (syslog)", "stel fysieke locatie huidige apparaat in",
		"geef de gebruikerstaal op (en, fr, de, it, es, nl)",
		"geef licentie en versienummer weer",
		"sta meerdere instanties van deze toepassing toe",
		"geef gedetecteerde apparaten met hun fysieke locaties",
		"Contact: Guillemot Corporation S.A., BP2, 56204 La Gacilly Cedex, France or\n         <http://ts.hercules.com/nl/index.php?pg=email>.",
		};


	if (nString_ID<IDS_MIN || nString_ID>IDS_MAX)
	{
		DEBUG_PRINT("Error: querying an out of range string ID #%d!", nString_ID);
		return 0;
	}

	switch(m_nLanguageID)
	{
		case LANGID_FRENCH:
			return SZ_FRENCH[nString_ID-IDS_MIN];
		case LANGID_GERMAN:
			return SZ_GERMAN[nString_ID-IDS_MIN];
		case LANGID_ITALIAN:
			return SZ_ITALIAN[nString_ID-IDS_MIN];
		case LANGID_SPANNISH:
			return SZ_SPANNISH[nString_ID-IDS_MIN];
		case LANGID_DUTCH:
			return SZ_DUTCH[nString_ID-IDS_MIN];
		case LANGID_ENGLISH:
		default:
			return SZ_ENGLISH[nString_ID-IDS_MIN];
	}

	return 0;
}


